@@ -350,7 +350,7 @@ class JunosDevice(linux.LinuxDevice):
                 parse = "redundancy-group", log_level = self.LOG_DEBUG)
         self.isha = cluster and True or False
 
-        if self.model.lower() in ["srx320", "srx550m", "vSRX", "srx345"]:
+        if self.model.lower() in ["srx320", "srx550m", "vsrx", "srx345"]:
             spus = self.isha and ["node0.fwdd", "node1.fwdd"] or ["fwdd"]
         elif self.model.lower() in ["srx1500", "srx4100", "srx4200", "srx4600", "vsrx"]:
             spus = self.isha and ["node0.fpc0", "node1.fpc0"] or ["fpc0"]
