@@ -507,11 +507,12 @@ class LinuxDevice(object):
         thread_name = threading.current_thread().name
         name = self["name"] and self["name"] or self.name
 
-        l = "[%s%s\033[0m]" %(name_color, name)
         if self['log_time']:
             now = time.strftime('%Y%m%d %H:%M:%S',time.localtime(time.time()))
             #l += "[%s][%s]" %(now, thread_name)
-            l += "[%s]" %(now)
+            l = "[%s][%s%s\033[0m]" %(now, name_color, name)
+        else:
+            l = "[%s%s\033[0m]" %(name_color, name)
 
         f = StringIO(message)
         for i in f.readlines():
